@@ -4,7 +4,7 @@
 #'@param x The 3 categorical variables that you make matches for.
 #'@param y Your result variable.
 #'@param covs Enter the relevant covariates.
-#'@param factor Define categorical variables. You can leave this blank, but if you do, fill in at least 2.
+#'@param factor Define categorical variables.
 #'@return A data.
 #'
 #'
@@ -12,10 +12,14 @@
 pm3datalist<-function(data,x,y,covs,factor=NULL){
   data<-as.data.frame(data)
   data<-na.omit(data)
-  if (!missing(factor)) {fac<-factor}
+  fac<-factor
   data[,x]<-as.numeric(as.factor(data[,x]))
-  a<-unique(data[,x]);a<-sort(a);b<-c(1,2,3)
+  a<-unique(data[,x]);b<-c(1,2,3)
   if (identical(a,b) !=TRUE)  {stop("X must be 3 categories.")}
-  if (!missing(factor)) {data[,c(fac)] <- lapply(data[,c(fac)], factor)}
+  if (!missing(factor)) {
+    for(i in factor){
+      data[,i] <- as.factor(data[,i])
+    }
+  }
   data
 }
